@@ -5,6 +5,8 @@ using namespace std;
 #include <cstdlib>
 #include <cstring> // for memcpy
 
+using namespace rgl;
+
 //
 // COLOR UTILS
 //
@@ -14,7 +16,7 @@ using namespace std;
 //   HexCharToNibble
 //
 
-u8 HexCharToNibble(char c) {
+static u8 HexCharToNibble(char c) {
   u8 nibble = 0;
 
   if ((c >= '0') && (c <= '9'))
