@@ -4,12 +4,13 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: Device.hpp 947 2013-07-18 00:36:47Z murdoch $
+// $Id$
 
 #include "Disposable.hpp"
 #include "types.h"
 #include "rglview.h"
 
+namespace rgl {
 
 //
 // class Device
@@ -73,5 +74,7 @@ private:
   int    id_;
 };
 
+} // namespace rgl
+
 #endif // RGL_DEVICE_HPP
 
