@@ -4,12 +4,14 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: DeviceManager.hpp 952 2013-07-24 22:38:45Z murdoch $
+// $Id$
 
 #include "Device.hpp"
 
 #include <list>
 
+namespace rgl {
+
 /**
  * Manager component that is used as a front-end for multiple devices access
  * using an 'id' to set the current device.
@@ -44,5 +46,7 @@ private:
   bool	    useNULLDevice;
 };
 
+} // namespace rgl
+
 #endif // DEVICE_MANAGER_HPP
 
