@@ -3,6 +3,8 @@
 
 #include <vector>
 
+namespace rgl {
+
 // forward declaration
 class Disposable;
 
@@ -51,5 +53,7 @@ private:
   Container disposeListeners;
 };
 
+} // namespace rgl
+
 #endif // RGL_DISPOSABLE_HPP
 
