@@ -4,10 +4,12 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: fps.h 376 2005-08-03 23:58:47Z dadler $
+// $Id$
 
 #include "scene.h"
 
+namespace rgl {
+
 //
 // FPS COUNTER
 //
@@ -24,5 +26,7 @@ public:
   void render(double t, RenderContext* ctx);
 };
 
+} // namespace rgl
+
 #endif // RGL_FPS_H
 
