@@ -1,14 +1,21 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: glgui.cpp 957 2013-08-20 18:25:15Z murdoch $
+// $Id$
 
+#include <cstdio>
+#ifdef HAVE_FREETYPE
+#include "FTGL/ftgl.h"
+#include "R.h"
+#endif
 #include "types.h"
 #include "glgui.hpp"
 #include "gl2ps.h"
 #include "opengl.hpp"
 #include "RenderContext.hpp"
 
+using namespace rgl;
+
 //
 // CLASS
 //   GLFont
@@ -116,9 +123,6 @@ void GLBitmapFont::draw(const wchar_t* text, int length,
 
 #ifdef HAVE_FREETYPE
 
-#include "FTGL/ftgl.h"
-#include "R.h"
-
 GLFTFont::GLFTFont(const char* in_family, int in_style, double in_cex, const char* in_fontname) 
 : GLFont(in_family, in_style, in_cex, in_fontname, true)
 {
