@@ -1,9 +1,11 @@
 #ifndef RGL_LIB_HPP
 #define RGL_LIB_HPP
 // ---------------------------------------------------------------------------
-// $Id: lib.hpp 947 2013-07-18 00:36:47Z murdoch $
+// $Id$
 // ---------------------------------------------------------------------------
-namespace lib {
+
+namespace rgl {
+
 // ---------------------------------------------------------------------------
 bool init(bool onlyNULLDevice);
 const char * GUIFactoryName(bool useNULLDevice);    
@@ -11,7 +13,8 @@ void quit();
 void printMessage(const char* string);
 double getTime();
 // ---------------------------------------------------------------------------
-} // namespace lib
-// ---------------------------------------------------------------------------
+
+} // namespace rgl
+
 #endif // RGL_LIB_HPP
 
