@@ -4,7 +4,7 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: rglmath.h 806 2011-04-26 18:53:13Z murdoch $
+// $Id$
 
 
 using namespace std;
@@ -18,6 +18,8 @@ using namespace std;
 #define M_PI      3.1415926535897932384626433832795
 #endif
 
+namespace rgl {
+
 namespace math {
 
   // template-based math functions with default 'double' implementation using math.h
@@ -208,4 +210,6 @@ struct PolarCoord
 
 typedef Vec4 Vertex4;
 
+} // namespace rgl
+
 #endif /* MATH_H */
