@@ -4,10 +4,12 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: select.h 384 2005-08-04 22:32:13Z dadler $
+// $Id$
 
 #include "scene.h"
 
+namespace rgl {
+
 //
 // Mouse selection rectangle
 //
@@ -19,5 +21,7 @@ public:
   void render(double* position);
 };
 
+} // namespace rgl
+
 #endif // PLX_SELECT_H
 
