@@ -1,15 +1,15 @@
 #ifndef RGL_TYPES_H
 #define RGL_TYPES_H
 
+#include <cstring>
 #include "pragma.h"
 
 // C++ header file
 // This file is part of RGL
 //
-// $Id: types.h 880 2012-05-08 11:54:12Z murdoch $
+// $Id$
 
-
-#include <cstring>
+namespace rgl {
 
 //
 //
@@ -155,5 +155,7 @@ inline float getMax(float a, float b) { return (a >= b) ? a : b; }
 inline float clamp(float v, float floor, float ceil) { return (v<floor) ? floor : ( (v>ceil) ? ceil : v ); }
 inline int   clamp(int   v, int   floor, int   ceil) { return (v<floor) ? floor : ( (v>ceil) ? ceil : v ); }
 
+} // namespace rgl
+
 #endif /* RGL_TYPES_H */
 
